#!/usr/bin/env python3

from distutils.core import setup

setup( name="plutoid",
    version = "0.1.0",
    description = "A light weight Python kernel",
    author = "Manas Garg",
    author_email = "manasgarg@gmail.com",
    license = "MIT",
    url = "https://github.com/manasgarg/plutoid",
    packages = ["plutoid"],
    long_description = "Plutoid is a light weight Python kernel that can be used for adding code execution capabilities to programming education applications.",
    python_requires='~=3.6',
)